@@ -1,5 +1,5 @@
 
-;; Copyright (C) 2020, 2022, 2023 Tommi Höynälänmaa
+;; Copyright (C) 2020, 2022-2024 Tommi Höynälänmaa
 
 ;; This file is part of Theme-D-Intr.
 
@@ -34,10 +34,4 @@
   (Gtk HSeparator)
   (Gtk TextTagTable)
   (Gtk TextTag)
-  (Gtk TextMark))
- (overridden-functions
-  (gtk-text-buffer-insert (<gtk-text-buffer> <pointer> <string>)
-			  <none> nonpure)
-  (g-application-run (<g-application> (:uniform-list <string>))
-		     <integer> nonpure)))
-
+  (Gtk TextMark)))
