@@ -1,5 +1,5 @@
 
-;; Copyright (C) 2020, 2022 Tommi Höynälänmaa
+;; Copyright (C) 2020, 2022, 2024 Tommi Höynälänmaa
 
 ;; This file is part of Theme-D-Intr.
 
@@ -23,7 +23,4 @@
   (Gtk Widget)
   (Gtk Application)
   (Gtk ApplicationWindow)
-  (Gtk Button))
- (overridden-functions
-  (g-application-run (<g-application> (:uniform-list <string>))
-		     <integer> nonpure)))
+  (Gtk Button)))
