@@ -1,5 +1,5 @@
 
-;; Copyright (C) 2020, 2022 Tommi Höynälänmaa
+;; Copyright (C) 2020, 2022, 2024 Tommi Höynälänmaa
 
 ;; This file is part of Theme-D-Intr.
 
@@ -25,7 +25,4 @@
   (Gtk ApplicationWindow)
   (Gtk Button))
  (strip-boolean-result
-  gtk-widget-intersect)
- (overridden-functions
-  (g-application-run (<g-application> (:uniform-list <string>))
-		     <integer> nonpure)))
+  gtk-widget-intersect))
