@@ -1,5 +1,5 @@
 
-;; Copyright (C) 2020, 2021 Tommi Höynälänmaa
+;; Copyright (C) 2020, 2021, 2024 Tommi Höynälänmaa
 
 ;; This file is part of Theme-D-Golf.
 
@@ -864,9 +864,16 @@
 	     ;;    (newline)
 	     ;;    #f))
 	     (l-arguments0 (!arguments x-function))
+	     (o-spec-pos (!o-spec-pos x-function))
 	     (l-arguments
-	      (filter (lambda (gi-arg) (not (eq? (!direction gi-arg) 'out)))
-		      l-arguments0))
+	      (if o-spec-pos
+		  (map (lambda (pos)
+			 (list-ref l-arguments0 pos))
+		       o-spec-pos)
+		  (filter (lambda (gi-arg)
+			    (and (not (eq? (!direction gi-arg) 'out))
+				 (not (!al-arg? gi-arg))))
+			  l-arguments0)))
 	     (l-argument-types (map get-argument-type l-arguments))
 	     (x-return-type-tag (!return-type x-function))
 	     (x-return-type0 (!type-desc x-function))
